==> qt-creator-opensource-src-4.10.2.zip: qt-creator-opensource-src-4.10.2/src/plugins/beautifier/uncrustify/uncrustifyoptionspage.h <==
/****************************************************************************
**
** Copyright (C) 2016 Lorenz Haas
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <coreplugin/dialogs/ioptionspage.h>

#include <QPointer>
#include <QWidget>

namespace Beautifier {
namespace Internal {
namespace Uncrustify {

class UncrustifySettings;

namespace Ui { class UncrustifyOptionsPage; }

class UncrustifyOptionsPageWidget : public QWidget
{
    Q_OBJECT

public:
    explicit UncrustifyOptionsPageWidget(UncrustifySettings *settings, QWidget *parent = nullptr);
    ~UncrustifyOptionsPageWidget() override;
    void restore();
    void apply();

private:
    Ui::UncrustifyOptionsPage *ui;
    UncrustifySettings *m_settings;
};

class UncrustifyOptionsPage : public Core::IOptionsPage
{
    Q_OBJECT

public:
    explicit UncrustifyOptionsPage(UncrustifySettings *settings, QObject *parent = nullptr);
    QWidget *widget() override;
    void apply() override;
    void finish() override;

private:
    QPointer<UncrustifyOptionsPageWidget> m_widget;
    UncrustifySettings *m_settings;
};

} // namespace Uncrustify
} // namespace Internal
} // namespace Beautifier

==> qt-creator-opensource-src-4.12.1.zip: qt-creator-opensource-src-4.12.1/src/plugins/beautifier/uncrustify/uncrustifyoptionspage.h <==
/****************************************************************************
**
** Copyright (C) 2016 Lorenz Haas
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <coreplugin/dialogs/ioptionspage.h>

namespace Beautifier {
namespace Internal {
namespace Uncrustify {

class UncrustifySettings;

class UncrustifyOptionsPage final : public Core::IOptionsPage
{
public:
    explicit UncrustifyOptionsPage(UncrustifySettings *settings);
};

} // namespace Uncrustify
} // namespace Internal
} // namespace Beautifier
